# Support

## How to file issues and get help  

This project uses GitHub Issues to track bugs and feature requests. Please search the existing 
issues before filing new issues to avoid duplicates.  For new issues, file your bug or 
feature request as a new Issue.

For help and questions about using this project, please check the existing GitHub Issues or create a new issue. You can also refer to the project documentation for usage examples and API reference.

## Microsoft Support Policy  

Support for this **openaivec** is limited to the resources listed above.
